/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef OPERATION_H
#define OPERATION_H		1

#include "common.h"

/* Number of recognizable tags */
#define NUM_OF_TAGS	13

/* Table of tag strings */
#define TAG_TABLE \
{ \
  "own-call", "own-name" , "own-qth" ,\
  "own-loc" , "own-rst"  , "rem-call",\
  "rem-name", "rem-qth"  , "rem-loc" ,\
  "rem-rst" , "date-time", "op-freq" ,\
  "app-version" \
}

#endif

